@@ -25,11 +25,11 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =head1 VERSION
 
-Version 3.2.0
+Version 3.2.1
 
 =cut
 
-our $VERSION = '3.2.0';
+our $VERSION = '3.2.1';
 
 =head1 SYNOPSIS
 
@@ -182,7 +182,7 @@ sub page_token {
     }
 
     state $x = require MIME::Base64;
-    MIME::Base64::encode_base64(pack('C*', @f, 16, 0)) =~ tr/=//dr;
+    MIME::Base64::encode_base64(pack('C*', @f, 16, 0)) =~ tr/=\n//dr;
 }
 
 =head2 escape_string($string)
@@ -695,7 +695,7 @@ sub post_as_json {
             my ($self, $url, $token) = @_;
 
             my $pt_url = (
-                            $url =~ s/[?&]pageToken=\K\w+/$token/
+                            $url =~ s/[?&]pageToken=\K[^&]+/$token/
                           ? $url
                           : $self->_append_url_args($url, pageToken => $token)
                          );
